@@ -1,15 +1,14 @@
-import json
 import os
 import sys
 import platform
 import threading
 import traceback
 
-from .api_call import api_call, api_auth
+from .api_handler import APIHandler
 from .account import Account
 from .user import User
 
-__version__ = "1.0.6"
+__version__ = "1.0.8"
 
 
 class FreedomClient(object):
@@ -24,37 +23,16 @@ class FreedomClient(object):
         password (str): Password.
     """
 
-    def __init__(self, token =None, secret =None, username=None, password=None, url=None):
-        # if class is initialized with a token and secret, use it
-        if token is not None and secret is not None:
-            self.token = token
-            self.secret = secret
-            api_auth(self.token, self.secret, url=url)
-
-        # if class is initialized with a username and password, use it
-        elif username is not None and password is not None:
-            response = api_call(
-                "PUT", 
-                "/users/{}/login".format(username),
-                data={
-                    "password": password
-                },
-                no_auth=True)
-            self.token = response.get("token")
-            self.secret = response.get("secret")
-            api_auth(self.token, self.secret, url=url)
-
-        # if there is a saved freedom credentials file, use it
-        elif os.path.exists(os.path.expanduser("~/.freedom_credentials")):
-            with open(os.path.expanduser("~/.freedom_credentials")) as f:
-                credentials = json.load(f)
-                if url is None:
-                    url = credentials.get("url", "https://api.freedomrobotics.ai/")
-                self.token = credentials.get("token")
-                self.secret = credentials.get("secret")
-                api_auth(self.token, self.secret, url=url)
-        else:
-            raise Exception("Required: either token/secret, username/password, or saved ~/.freedom_credentials file")
+    def __init__(self, token=None, secret=None, username=None, password=None, url=None, **api_args):
+        self.api = APIHandler.get_instance(
+            url=url,
+            token=token,
+            secret=secret,
+            username=username,
+            password=password,
+            **api_args
+        )
+        assert self.api is not None
 
     def get_account(self, account_id):
         """:obj:`Account`: Fetch an account by its account ID (Axxxxxxxxxxxx).
@@ -63,34 +41,37 @@ class FreedomClient(object):
             account_id (str): Account ID.
         """
 
-        account_data = api_call("GET", "/accounts/{}".format(account_id))
+        account_data = self.api.call("GET", "/accounts/{}".format(account_id))
         if not account_data:
             return None
-        return Account(account_data["account"], account_data)
+        return Account(account_data["account"], account_data, api=self.api)
 
     def get_accounts(self):
         """:obj:`list` of :obj:`Account`: Fetch a list of all accounts that are visible/accessible.
         """
 
-        result = api_call("GET", "/accounts")
+        result = self.api.call("GET", "/accounts")
         if not result:
             return []
-        return [Account(account_data["account"], account_data) for account_data in result]
+        return [
+            Account(account_data["account"], account_data, api=self.api)
+            for account_data in result
+        ]
 
     def get_users(self):
         """:obj:`list` of :obj:`User`: Fetch a list of all users that are visible/accessible.
         """
 
-        result = api_call("GET", "/users")
+        result = self.api.call("GET", "/users")
         if not result:
             return []
-        return [User(user_data["user"], user_data) for user_data in result]
+        return [User(user_data["user"], user_data, api=self.api) for user_data in result]
 
     def get_tokens(self):
         """:obj:`list` of :obj:`dict`: Fetch a list of tokens.
         """
 
-        result = api_call("GET", "/accounts")
+        result = self.api.call("GET", "/accounts")
         return result
 
     def report_issue(self, message, level, logs=None, account=None, device=None, user=None, **kwargs):
@@ -112,7 +93,7 @@ class FreedomClient(object):
             )
 
         freedom_data = {
-            "token": '*' * 3 + self.token[-8:],
+            "token": '*' * 3 + self.api.token[-8:],
         }
         if account is not None:
             freedom_data['account'] = account
@@ -161,4 +142,4 @@ class FreedomClient(object):
         }
         data.update(kwargs)
 
-        api_call("PUT", "/issues", data=data)
+        self.api.call("PUT", "/issues", data=data)
