@@ -1,6 +1,6 @@
 import json
 import time
-from .api_call import api_call
+
 from .alert import Alert
 from .entity import Entity
 from .helpers import to_unix_time
@@ -19,7 +19,7 @@ class Device(Entity):
             "expiration_secs": expiration_secs,
             "platform": platform,
         }
-        return api_call(
+        return self.api.call(
             "PUT",
             "/accounts/{}/devices/{}/commands".format(self.account, self._id),
             data=cmd
@@ -38,7 +38,7 @@ class Device(Entity):
         return self._data.get("compute_architecture")
 
     def create_token(self):
-        response = api_call(
+        response = self.api.call(
             "POST",
             "/tokens?create_secret=true",
             data = {
@@ -151,7 +151,7 @@ class Device(Entity):
             },
         ]
 
-        response = api_call(
+        response = self.api.call(
             "PUT",
             "/accounts/%s/devices/%s/commands" % (
                 self._data.get("account"),
@@ -189,7 +189,7 @@ class Device(Entity):
         params["pagination_direction"] = direction
 
         while True:
-            result = api_call(
+            result = self.api.call(
                 "GET",
                 "/accounts/{}/devices/{}/data/".format(self.account, self._id),
                 params=params
@@ -243,7 +243,7 @@ class Device(Entity):
         if topics is not None:
             params["topics"] = json.dumps(topics)
 
-        result = api_call(
+        result = self.api.call(
             "GET",
             "/accounts/{}/devices/{}/statistics/".format(self.account, self._id),
             params=params
@@ -280,7 +280,7 @@ class Device(Entity):
         if utc_end is not None:
             params["utc_end"] = utc_end
 
-        result = api_call(
+        result = self.api.call(
             "GET",
             "/accounts/{}/devices/{}/statistics/".format(self.account, self._id),
             params=params
@@ -295,9 +295,8 @@ class Device(Entity):
             More info about the object format can be found on API docs:
             https://docs.freedomrobotics.ai/reference#rest-api
         """
-
-        api_call(
+        self.api.call(
             "PUT",
             "/accounts/{}/devices/{}/statistics/".format(self.account, self._id),
             data=data
-        )
\ No newline at end of file
+        )
